@@ -1,6 +1,6 @@
-import bson
-import struct
-import re
+from base64 import b64decode, b64encode
+from bson import ObjectId
+from struct import pack, unpack
 from decimal import Decimal
 from simpleeval import SimpleEval, DEFAULT_FUNCTIONS
 
@@ -8,6 +8,14 @@ g_s = SimpleEval()
 g_s.functions = DEFAULT_FUNCTIONS.copy()
 
 
+def base64_encode(datas: bytes) -> str:
+    return b64encode(datas).decode()
+
+
+def base64_decode(datas: str) -> bytes:
+    return b64decode(datas)
+
+
 def chunk_list(values: list, num: int):
     for i in range(0, len(values), num):
         yield values[i: i+num]
@@ -24,7 +32,7 @@ def convert_class_to_dict(obeject_class):
 
 
 def generate_object_id():
-    return bson.ObjectId().__str__()
+    return ObjectId().__str__()
 
 
 def remove_exponent(value: Decimal):
@@ -33,7 +41,7 @@ def remove_exponent(value: Decimal):
 
 def remove_exponent_str(value: str) -> str:
     dec_value = Decimal(value)
-    if dec_value == dec_value.to_integral(): # int
+    if dec_value == dec_value.to_integral():    # int
         return str(int(float(value)))
     else:
         return value.rstrip('0')
@@ -69,7 +77,9 @@ def revert_exp(scale: str) -> str:
 "com(v)"   #自定义函数 bit signed inverse_long inverse_float inverse_double
 "1 if v == 20.1234 else 0" #表达式
 '''
-def format_value(value_old: str, scale: str='1', decimal: int = 2, revert: bool = False) -> str:
+
+
+def format_value(value_old: str, scale: str = '1', decimal: int = 2, revert: bool = False) -> str:
     value = str(value_old)
     scale = '1' if scale == '' else scale
     is_scale_num, scale = is_number(str(scale))
@@ -95,73 +105,78 @@ def format_value(value_old: str, scale: str='1', decimal: int = 2, revert: bool
                 if is_value_num is True:
                     d = Decimal(str(value))
                     if -d.as_tuple().exponent > decimal:
-                        format = f"%.{decimal}f"
-                        value = format % value  # 格式化小数点
+                        _format = f"%.{decimal}f"
+                        value = _format % value  # 格式化小数点
                     value = remove_exponent_str(str(value))
             return str(value)
-        except Exception as e:
+        except Exception:
             pass
     return str(value_old)
 
+
 # 自定义
 # 取位函数
 def bit(value, index: int):
     try:
         value = int(value)
         return value & (1 << index) and 1 or 0
-    except:
+    except Exception:
         pass
     return value
 
+
 def signed(value):
     try:
         value = int(value)
-        return struct.unpack('h', struct.pack('H', value))[0]
-    except:
+        return unpack('h', pack('H', value))[0]
+    except Exception:
         pass
     return value
 
+
 def inverse_long(value):
     try:
         value = int(float(value))
-        vev_value = struct.unpack('HH', struct.pack('L', value))
-        return struct.unpack('L', struct.pack('HH', vev_value[1], vev_value[0]))[0]
-    except:
+        vev_value = unpack('HH', pack('L', value))
+        return unpack('L', pack('HH', vev_value[1], vev_value[0]))[0]
+    except Exception:
         pass
     return value
 
+
 def inverse_float(value):
     try:
         value = float(value)
-        vev_value = struct.unpack('HH', struct.pack('f', value))
-        return struct.unpack('f', struct.pack('HH', vev_value[1], vev_value[0]))[0]
-    except:
+        vev_value = unpack('HH', pack('f', value))
+        return unpack('f', pack('HH', vev_value[1], vev_value[0]))[0]
+    except Exception:
         pass
     return value
 
+
 def inverse_double(value):
     try:
         value = float(value)
-        vev_value = struct.unpack('HHHH', struct.pack('d', value))
-        return struct.unpack('d', struct.pack('HHHH', vev_value[3], vev_value[2], vev_value[1], vev_value[0]))[0]
-    except:
+        vev_value = unpack('HHHH', pack('d', value))
+        return unpack('d', pack('HHHH', vev_value[3], vev_value[2], vev_value[1], vev_value[0]))[0]
+    except Exception:
         pass
     return value
 
+
 def _and(*args):
     start = 1
     for a in args:
         start = start & a
     return start
 
+
 def _or(*args):
     start = 0
     for a in args:
         start = start | a
     return start
 
+
 # 添加自定义函数
 g_s.functions.update(max=max, min=min, bit=bit, signed=signed, inverse_long=inverse_long, inverse_float=inverse_float, inverse_double=inverse_double, _and=_and, _or=_or)
-
-
-
