@@ -2,11 +2,13 @@ import os
 import sys
 import argparse
 import platform
-import uuid
 import time
 
 import psutil
 import subprocess
+
+from uuid import UUID, getnode
+from typing import Optional
 from ..cls.utils import daemon_thread
 
 
@@ -17,10 +19,13 @@ def is_pid_exist(pid: int):
 
 def kill_pid(pid: int):
     if is_pid_exist(pid) is True:
-        #os.popen(f"taskkill.exe /F /t /pid:{pid}")
         os.kill(pid, 9)
 
 
+def kill_process(name: str):
+    os.popen(f"taskkill /im {name} -f")
+
+
 # 显示全部进程
 def get_all_pids():
     return psutil.pids()
@@ -54,14 +59,15 @@ def get_process_name(pid: int):
     return psutil.Process(pid).name()
 
 
-def get_process_by_path(path: str):
-    process_dir = os.path.dirname(path).replace('\\','/')
-    process_name = os.path.basename(path)
-    process_ext = os.path.splitext(path)[-1][1:]  # 进程后缀名
+def get_process_by_name(process_name: str, process_dir: Optional[str] = None):
+    process_ext = os.path.splitext(process_name)[-1][1:]  # 进程后缀名
     for process in psutil.process_iter():
         if process_ext == 'exe':
             if process.name() == process_name:
-                if process.cwd().replace('\\', '/') == process_dir:
+                if process_dir is not None:
+                    if process.cwd().replace('\\', '/') == process_dir:
+                        return process.pid
+                else:
                     return process.pid
         elif process_ext == 'py':
             if process.name() == 'python.exe':
@@ -70,6 +76,12 @@ def get_process_by_path(path: str):
     return -1
 
 
+def get_process_by_path(path: str):
+    process_dir = os.path.dirname(path).replace('\\', '/')
+    process_name = os.path.basename(path)
+    return get_process_by_name(process_name, process_dir)
+
+
 def close_dump(child_id: int):
     # 检测崩溃弹框，关闭掉
     parser = argparse.ArgumentParser()
@@ -88,7 +100,7 @@ def close_dump(child_id: int):
 
 
 # 关闭进程
-def close_process(pid: int, dump_close: bool=True):
+def close_process(pid: int, dump_close: bool = True):
     if dump_close is True:
         close_dump(pid)
 
@@ -120,8 +132,9 @@ def restart_process(process_path: str):
 # 开机自启动
 def auto_start(app_path: str):
     if platform.system().lower() == 'windows':
-        import win32api
         import win32con
+        from win32api import RegOpenKey, RegQueryValueEx, RegSetValueEx, RegCloseKey
+        from win32con import KEY_ALL_ACCESS, HKEY_CURRENT_USER
         app_name = os.path.basename(app_path)
         app_ext = os.path.splitext(app_path)[1]
         reg_path = app_path
@@ -138,16 +151,16 @@ def auto_start(app_path: str):
                 f.write(f"start {app_name}\n")
                 f.write(f"exit")
 
-        key = win32api.RegOpenKey(win32con.HKEY_CURRENT_USER, 'Software\\Microsoft\\Windows\\CurrentVersion\\Run', 0, win32con.KEY_ALL_ACCESS)
+        key = RegOpenKey(HKEY_CURRENT_USER, 'Software\\Microsoft\\Windows\\CurrentVersion\\Run', 0, KEY_ALL_ACCESS)
         try:
-            reg_tuple = win32api.RegQueryValueEx(key, reg_name)
+            reg_tuple = RegQueryValueEx(key, reg_name)
             if len(reg_tuple) > 0 and reg_tuple[0] != reg_path:
-                win32api.RegSetValueEx(key, reg_name, 0, win32con.REG_SZ, reg_path)
-                win32api.RegCloseKey(key)
+                RegSetValueEx(key, reg_name, 0, win32con.REG_SZ, reg_path)
+                RegCloseKey(key)
             return True
-        except:
-            win32api.RegSetValueEx(key, reg_name, 0, win32con.REG_SZ, reg_path)
-            win32api.RegCloseKey(key)
+        except Exception:
+            RegSetValueEx(key, reg_name, 0, win32con.REG_SZ, reg_path)
+            RegCloseKey(key)
     return False
 
 
@@ -206,25 +219,25 @@ def update(update_path: str):
 # 重置控制台属性
 def reset_console_property():
     if platform.system().lower() == 'windows':
-        STD_INPUT_HANDLE = -10
-        ENABLE_QUICK_EDIT_MODE = 0x0040
-        ENABLE_MOUSE_INPUT = 0x0010
-        ENABLE_INSERT_MODE = 0x0020
+        std_input_handle = -10
+        enable_quick_edit_mode = 0x0040
+        enable_insert_mode = 0x0010
+        enable_mouse_input = 0x0020
         from ctypes import windll, c_int, byref
-        handle = windll.kernel32.GetStdHandle(STD_INPUT_HANDLE)
+        handle = windll.kernel32.GetStdHandle(std_input_handle)
         if handle:
-            inMode = c_int(0)
-            windll.kernel32.GetConsoleMode(c_int(handle), byref(inMode))
+            in_mode = c_int(0)
+            windll.kernel32.GetConsoleMode(c_int(handle), byref(in_mode))
 
-            inMode = c_int(inMode.value & ~ENABLE_QUICK_EDIT_MODE)  # 移除快速编辑模式
-            inMode = c_int(inMode.value & ~ENABLE_INSERT_MODE)  # 移除插入模式
-            inMode = c_int(inMode.value & ~ENABLE_MOUSE_INPUT)  #
-            windll.kernel32.SetConsoleMode(c_int(handle), inMode)
+            in_mode = c_int(in_mode.value & ~enable_quick_edit_mode)  # 移除快速编辑模式
+            in_mode = c_int(in_mode.value & ~enable_insert_mode)  # 移除插入模式
+            in_mode = c_int(in_mode.value & ~enable_mouse_input)  #
+            windll.kernel32.SetConsoleMode(c_int(handle), in_mode)
 
 
 # 获取MAC地址
 def get_mac_address():
-    mac = uuid.UUID(int=uuid.getnode()).hex[-12:]
+    mac = UUID(int=getnode()).hex[-12:]
     return ":".join([mac[e:e + 2] for e in range(0, 11, 2)]).upper()
 
 
@@ -245,9 +258,9 @@ class SingleInstance:
             self.lasterror = GetLastError()
 
     def aleradyrunning(self) -> bool:
-        return (self.lasterror == 183)
+        return self.lasterror == 183
 
     def __del__(self):
         if self.mutex:
             from win32api import CloseHandle
-            CloseHandle(self.mutex)
\ No newline at end of file
+            CloseHandle(self.mutex)
