@@ -55,3 +55,8 @@ def contain_match(value: str, filters: str = '') -> bool:
     if re.compile(f".*?{pattern}.*?").search(value):
         return True
     return False
+
+
+# 查找全部
+def find_match(value: str, pattern: str = r'.*?<%(\w+)%>.*?') -> list:
+    return re.findall(pattern, value)
\ No newline at end of file
