@@ -71,4 +71,10 @@ def test_chunk_list():
     print(len(ab))
 
 
-test_nvn_value()
\ No newline at end of file
+def test_large():
+    result = format_value('0.1', '0.15 if v>5 else v', 2)
+    print(result)
+    print(format_value('2', '(max(4, v*3.3*1000/(4095*150))-4)/16*100', 3))
+
+
+test_large()
\ No newline at end of file
